@@ -1,3 +1,5 @@
+import re
+
 from django.core import mail
 from django.core.mail import EmailMultiAlternatives
 from django.test import TestCase
@@ -119,6 +121,18 @@ class EmailTestServiceTest(TestCase):
         qs = self.ets.filter(to=self.to, cc=self.cc, bcc=self.bcc, subject='Not my subject')
         self.assertEqual(qs.count(), 0)
 
+    def test_filter_subject_regex_invalid(self):
+        qs = self.ets.filter(subject=re.compile('Not my subject'))
+        self.assertEqual(qs.count(), 0)
+
+    def test_filter_subject_regex_valid_single(self):
+        qs = self.ets.filter(subject=re.compile('definitely not'))
+        self.assertEqual(qs.count(), 1)
+
+    def test_filter_subject_regex_valid_multiple(self):
+        qs = self.ets.filter(subject=re.compile('other|spam', flags=re.IGNORECASE))
+        self.assertEqual(qs.count(), 2)
+
     def test_all(self):
         # Assertion
         self.assertEqual(self.ets.all().count(), 2)
